# Taism2
Simulation Library for Intelligent Multi-Robot Systems
![base_logo_transparent_background](taisim.png)

## Instalation
```sh
python3 -m pip install pygame pyOpenGL opencv-python
```

TODO Adding binary files
